@@ -1,6 +1,6 @@
 package Pod::Weaver::Plugin::Transformer;
 {
-  $Pod::Weaver::Plugin::Transformer::VERSION = '3.101637';
+  $Pod::Weaver::Plugin::Transformer::VERSION = '4.006';
 }
 use Moose;
 with 'Pod::Weaver::Role::Dialect';
@@ -9,6 +9,7 @@ with 'Pod::Weaver::Role::Dialect';
 use namespace::autoclean;
 use Moose::Autobox;
 
+use Module::Runtime qw(use_module);
 use List::MoreUtils qw(part);
 use String::RewritePrefix;
 
@@ -29,7 +30,7 @@ sub BUILDARGS {
     delete $xform_args{transformer},
   );
 
-  Class::MOP::load_class($xform_class);
+  use_module($xform_class);
 
   my $plugin_name = delete $xform_args{plugin_name};
   my $weaver      = delete $xform_args{weaver};
@@ -53,15 +54,18 @@ sub translate_dialect {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Pod::Weaver::Plugin::Transformer - apply arbitrary transformers
 
 =head1 VERSION
 
-version 3.101637
+version 4.006
 
 =head1 OVERVIEW
 
@@ -87,10 +91,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
